News for shuft
==============

This file lists the major changes between versions. For a more detailed list of
every change, see the Git log.

Latest
------
* tbd

1.0.2
-----
* Patch: Packaginig fixes

1.0.1
-----
* Patch: Packaginig fixes

1.0.0
-----
* Initial release.
